# Welcome to rx!

This is your config directory. You can find info about your local repository,
your user login, and your remote configuration here. (This probably isn't of
interest to most users.)

See the [config documention](https://www.run-rx.com/config) for more info.
